@@ -20,14 +20,17 @@
 #include "config.h"
 #endif
 
+#include "plugin/gtd-plugin-dialog.h"
 #include "gtd-application.h"
 #include "gtd-initial-setup-window.h"
 #include "gtd-manager.h"
+#include "gtd-manager-protected.h"
 #include "gtd-window.h"
 
 #include <glib.h>
 #include <glib-object.h>
 #include <gio/gio.h>
+#include <girepository.h>
 #include <glib/gi18n.h>
 
 typedef struct
@@ -36,6 +39,7 @@ typedef struct
   GtdManager     *manager;
 
   GtkWidget      *window;
+  GtkWidget      *plugin_dialog;
   GtkWidget      *initial_setup;
 } GtdApplicationPrivate;
 
@@ -47,6 +51,10 @@ struct _GtdApplication
   GtdApplicationPrivate *priv;
 };
 
+static void           gtd_application_show_extensions             (GSimpleAction        *simple,
+                                                                   GVariant             *parameter,
+                                                                   gpointer              user_data);
+
 static void           gtd_application_show_about                  (GSimpleAction        *simple,
                                                                    GVariant             *parameter,
                                                                    gpointer              user_data);
@@ -58,11 +66,21 @@ static void           gtd_application_quit                        (GSimpleAction
 G_DEFINE_TYPE_WITH_PRIVATE (GtdApplication, gtd_application, GTK_TYPE_APPLICATION)
 
 static const GActionEntry gtd_application_entries[] = {
-  /*{ "new",    gtd_application_create_new_list },*/
+  { "show-extensions",  gtd_application_show_extensions },
   { "about",  gtd_application_show_about },
   { "quit",   gtd_application_quit }
 };
 
+static void
+gtd_application_show_extensions (GSimpleAction *simple,
+                                 GVariant      *parameter,
+                                 gpointer       user_data)
+{
+  GtdApplicationPrivate *priv = GTD_APPLICATION (user_data)->priv;
+
+  gtk_widget_show (priv->plugin_dialog);
+}
+
 static void
 gtd_application_show_about (GSimpleAction *simple,
                             GVariant      *parameter,
@@ -73,26 +91,28 @@ gtd_application_show_about (GSimpleAction *simple,
   GDateTime *date;
   int created_year = 2015;
 
-  date = g_date_time_new_now_local ();
-
-  const gchar *authors[] = {
+  static const gchar *authors[] = {
     "Georges Basile Stavracas Neto <georges.stavracas@gmail.com>",
+    "Emmanuele Bassi <ebassi@gnome.org>",
     NULL
   };
 
-  const gchar *artists[] = {
+  static const gchar *artists[] = {
     "Allan Day <allanpday@gmail.com>",
+    "Jakub Steiner <jimmac@gmail.com>",
     NULL
   };
 
+  date = g_date_time_new_now_local ();
+
   if (g_date_time_get_year (date) == created_year)
     {
-      copyright = g_strdup_printf (_("Copyright \xC2\xA9 %Id "
+      copyright = g_strdup_printf (_("Copyright \xC2\xA9 %d "
                                      "The To Do authors"), created_year);
     }
   else
     {
-      copyright = g_strdup_printf (_("Copyright \xC2\xA9 %Id\xE2\x80\x93%Id "
+      copyright = g_strdup_printf (_("Copyright \xC2\xA9 %d\xE2\x80\x93%d "
                                      "The To Do authors"), created_year, g_date_time_get_year (date));
     }
 
@@ -128,6 +148,7 @@ gtd_application_new (void)
   return g_object_new (GTD_TYPE_APPLICATION,
                        "application-id", "org.gnome.Todo",
                        "flags", G_APPLICATION_FLAGS_NONE,
+                       "resource-base-path", "/org/gnome/todo",
                        NULL);
 }
 
@@ -141,11 +162,17 @@ run_window (GtdApplication *application)
   priv = application->priv;
 
   if (!priv->window)
-    priv->window = gtd_window_new (GTD_APPLICATION (application));
+    {
+      priv->window = gtd_window_new (GTD_APPLICATION (application));
+
+      gtk_window_set_transient_for (GTK_WINDOW (priv->plugin_dialog),
+                                    GTK_WINDOW (priv->window));
+    }
 
   gtk_widget_show (priv->window);
 }
 
+/*
 static void
 finish_initial_setup (GtdApplication *application)
 {
@@ -184,14 +211,12 @@ run_initial_setup (GtdApplication *application)
 
   gtk_widget_show (priv->initial_setup);
 }
+*/
 
 static void
 gtd_application_activate (GApplication *application)
 {
   GtdApplicationPrivate *priv = GTD_APPLICATION (application)->priv;
-  gboolean first_run;
-
-  first_run = gtd_manager_get_is_first_run (priv->manager);
 
   if (!priv->provider)
    {
@@ -223,18 +248,15 @@ gtd_application_activate (GApplication *application)
        }
    }
 
-  /* If it's the first run of To Do, it should run the initial setup window */
-  if (first_run)
-    run_initial_setup (GTD_APPLICATION (application));
-  else
-    run_window (GTD_APPLICATION (application));
+  /* FIXME: the initial setup is disabled for the 3.18 release because
+   * we can't create tasklists on GOA accounts.
+   */
+  run_window (GTD_APPLICATION (application));
 }
 
 static void
 gtd_application_finalize (GObject *object)
 {
-  GtdApplication *self = GTD_APPLICATION (object);
-
   G_OBJECT_CLASS (gtd_application_parent_class)->finalize (object);
 }
 
@@ -243,12 +265,6 @@ gtd_application_startup (GApplication *application)
 {
   GtdApplicationPrivate *priv = GTD_APPLICATION (application)->priv;
 
-  /* manager */
-  priv->manager = gtd_manager_new ();
-
-  /* app menu */
-  g_application_set_resource_base_path (application, "/org/gnome/todo");
-
   /* add actions */
   g_action_map_add_action_entries (G_ACTION_MAP (application),
                                    gtd_application_entries,
@@ -256,6 +272,25 @@ gtd_application_startup (GApplication *application)
                                    application);
 
   G_APPLICATION_CLASS (gtd_application_parent_class)->startup (application);
+
+  /* plugin dialog */
+  priv->plugin_dialog = gtd_plugin_dialog_new ();
+
+  /* manager */
+  priv->manager = gtd_manager_get_default ();
+  gtd_manager_load_plugins (priv->manager);
+}
+
+static gboolean
+gtd_application_local_command_line (GApplication   *application,
+                                    gchar        ***arguments,
+                                    gint           *exit_status)
+{
+  g_application_add_option_group (application, g_irepository_get_option_group());
+
+  return G_APPLICATION_CLASS (gtd_application_parent_class)->local_command_line (application,
+                                                                                 arguments,
+                                                                                 exit_status);
 }
 
 static void
@@ -268,6 +303,7 @@ gtd_application_class_init (GtdApplicationClass *klass)
 
   application_class->activate = gtd_application_activate;
   application_class->startup = gtd_application_startup;
+  application_class->local_command_line = gtd_application_local_command_line;
 }
 
 static void
