@@ -51,13 +51,15 @@ typedef struct
   gboolean               show_completed;
   GList                 *list;
   GtdTaskList           *task_list;
-  GtdManager            *manager;
 
   /* color provider */
   GtkCssProvider        *color_provider;
 
   /* action */
   GActionGroup          *action_group;
+
+  GtdTaskListViewHeaderFunc header_func;
+  gpointer                  header_user_data;
 } GtdTaskListViewPrivate;
 
 struct _GtdTaskListView
@@ -68,7 +70,7 @@ struct _GtdTaskListView
   GtdTaskListViewPrivate *priv;
 };
 
-#define COLOR_TEMPLATE "GtkViewport {background-color: %s;}"
+#define COLOR_TEMPLATE "viewport {background-color: %s;}"
 #define LUMINANCE(c)   (0.299 * c->red + 0.587 * c->green + 0.114 * c->blue)
 
 #define TASK_REMOVED_NOTIFICATION_ID             "task-removed-id"
@@ -104,7 +106,6 @@ typedef struct
 
 enum {
   PROP_0,
-  PROP_MANAGER,
   PROP_READONLY,
   PROP_SHOW_COMPLETED,
   PROP_SHOW_LIST_NAME,
@@ -117,7 +118,7 @@ remove_task_action (GtdNotification *notification,
 {
   RemoveTaskData *data = user_data;
 
-  gtd_manager_remove_task (data->view->priv->manager, data->task);
+  gtd_manager_remove_task (gtd_manager_get_default (), data->task);
 
   g_free (data);
 }
@@ -146,6 +147,32 @@ undo_remove_task_action (GtdNotification *notification,
   g_free (data);
 }
 
+static void
+internal_header_func (GtdTaskRow      *row,
+                      GtdTaskRow      *before,
+                      GtdTaskListView *view)
+{
+  GtdTask *row_task;
+  GtdTask *before_task;
+
+  if (!view->priv->header_func || row == view->priv->new_task_row)
+    return;
+
+  row_task = before_task = NULL;
+
+  if (row)
+    row_task = gtd_task_row_get_task (row);
+
+  if (before)
+    before_task = gtd_task_row_get_task (before);
+
+  view->priv->header_func (GTK_LIST_BOX_ROW (row),
+                           row_task,
+                           GTK_LIST_BOX_ROW (before),
+                           before_task,
+                           view->priv->header_user_data);
+}
+
 static void
 update_font_color (GtdTaskListView *view)
 {
@@ -193,7 +220,7 @@ gtd_task_list_view__clear_completed_tasks (GSimpleAction *simple,
           list = gtd_task_get_list (l->data);
 
           gtd_task_list_remove_task (list, l->data);
-          gtd_manager_remove_task (view->priv->manager, l->data);
+          gtd_manager_remove_task (gtd_manager_get_default (), l->data);
         }
     }
 
@@ -317,7 +344,7 @@ gtd_task_list_view__edit_task_finished (GtdEditPane *pane,
 
   gtd_task_save (task);
 
-  gtd_manager_update_task (priv->manager, task);
+  gtd_manager_update_task (gtd_manager_get_default (), task);
   gtd_task_list_save_task (priv->task_list, task);
 
   gtk_list_box_invalidate_sort (priv->listbox);
@@ -558,7 +585,7 @@ gtd_task_list_view__task_completed (GObject    *object,
 
   task_complete = gtd_task_get_complete (task);
 
-  gtd_manager_update_task (priv->manager, task);
+  gtd_manager_update_task (gtd_manager_get_default (), task);
   gtd_task_list_save_task (gtd_task_get_list (task), task);
 
   if (task_complete)
@@ -630,7 +657,7 @@ gtd_task_list_view__create_task (GtdTaskRow *row,
   gtd_task_set_list (task, priv->task_list);
   gtd_task_list_save_task (priv->task_list, task);
 
-  gtd_manager_create_task (priv->manager, task);
+  gtd_manager_create_task (gtd_manager_get_default (), task);
 }
 
 static void
@@ -649,10 +676,6 @@ gtd_task_list_view_get_property (GObject    *object,
 
   switch (prop_id)
     {
-    case PROP_MANAGER:
-      g_value_set_object (value, self->priv->manager);
-      break;
-
     case PROP_SHOW_COMPLETED:
       g_value_set_boolean (value, self->priv->show_completed);
       break;
@@ -680,10 +703,6 @@ gtd_task_list_view_set_property (GObject      *object,
 
   switch (prop_id)
     {
-    case PROP_MANAGER:
-      gtd_task_list_view_set_manager (self, g_value_get_object (value));
-      break;
-
     case PROP_SHOW_COMPLETED:
       gtd_task_list_view_set_show_completed (self, g_value_get_boolean (value));
       break;
@@ -765,20 +784,6 @@ gtd_task_list_view_class_init (GtdTaskListViewClass *klass)
 
   widget_class->map = gtd_task_list_view_map;
 
-  /**
-   * GtdTaskListView::manager:
-   *
-   * A weak reference to the application's #GtdManager instance.
-   */
-  g_object_class_install_property (
-        object_class,
-        PROP_MANAGER,
-        g_param_spec_object ("manager",
-                             "Manager of this window's application",
-                             "The manager of the window's application",
-                             GTD_TYPE_MANAGER,
-                             G_PARAM_READWRITE));
-
   /**
    * GtdTaskListView::readonly:
    *
@@ -837,6 +842,8 @@ gtd_task_list_view_class_init (GtdTaskListViewClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, gtd_task_list_view__edit_task_finished);
   gtk_widget_class_bind_template_callback (widget_class, gtd_task_list_view__remove_task_cb);
   gtk_widget_class_bind_template_callback (widget_class, gtd_task_list_view__row_activated);
+
+  gtk_widget_class_set_css_name (widget_class, "task-list-view");
 }
 
 static void
@@ -861,7 +868,7 @@ gtd_task_list_view_init (GtdTaskListView *self)
  *
  * Creates a new #GtdTaskListView
  *
- * Returns: a newly allocated #GtdTaskListView
+ * Returns: (transfer full): a newly allocated #GtdTaskListView
  */
 GtkWidget*
 gtd_task_list_view_new (void)
@@ -877,7 +884,7 @@ gtd_task_list_view_new (void)
  * if a #GtdTaskList is set, the #GtdTaskList's list
  * of task will be returned.
  *
- * Returns: (element-type GtdTaskList) (transfer full): the internal list of
+ * Returns: (element-type Gtd.TaskList) (transfer full): the internal list of
  * tasks. Free with @g_list_free after use.
  */
 GList*
@@ -896,10 +903,9 @@ gtd_task_list_view_get_list (GtdTaskListView *view)
 /**
  * gtd_task_list_view_set_list:
  * @view: a #GtdTaskListView
+ * @list: (element-type Gtd.Task) (nullable): a list of tasks
  *
  * Copies the tasks from @list to @view.
- *
- * Returns:
  */
 void
 gtd_task_list_view_set_list (GtdTaskListView *view,
@@ -931,47 +937,6 @@ gtd_task_list_view_set_list (GtdTaskListView *view,
   gtd_task_list_view__update_empty_state (view);
 }
 
-/**
- * gtd_task_list_view_get_manager:
- * @view: a #GtdTaskListView
- *
- * Retrieves the #GtdManager from @view.
- *
- * Returns: (transfer none): the #GtdManager of @view
- */
-GtdManager*
-gtd_task_list_view_get_manager (GtdTaskListView *view)
-{
-  g_return_val_if_fail (GTD_IS_TASK_LIST_VIEW (view), NULL);
-
-  return view->priv->manager;
-}
-
-/**
- * gtd_task_list_view_set_manager:
- * @view: a #GtdTaskListView
- * @manager: a #GtdManager
- *
- * Sets the #GtdManager of @view.
- *
- * Returns:
- */
-void
-gtd_task_list_view_set_manager (GtdTaskListView *view,
-                                GtdManager      *manager)
-{
-  g_return_if_fail (GTD_IS_TASK_LIST_VIEW (view));
-  g_return_if_fail (GTD_IS_MANAGER (manager));
-
-  if (view->priv->manager != manager)
-    {
-      view->priv->manager = manager;
-      gtd_edit_pane_set_manager (GTD_EDIT_PANE (view->priv->edit_pane), manager);
-
-      g_object_notify (G_OBJECT (view), "manager");
-    }
-}
-
 /**
  * gtd_task_list_view_get_readonly:
  * @view: a #GtdTaskListView
@@ -993,8 +958,6 @@ gtd_task_list_view_get_readonly (GtdTaskListView *view)
  * @view: a #GtdTaskListView
  *
  * Sets the GtdTaskListView::readonly property of @view.
- *
- * Returns:
  */
 void
 gtd_task_list_view_set_readonly (GtdTaskListView *view,
@@ -1053,8 +1016,6 @@ gtd_task_list_view_get_task_list (GtdTaskListView *view)
  * @list: a #GtdTaskList
  *
  * Sets the internal #GtdTaskList of @view.
- *
- * Returns:
  */
 void
 gtd_task_list_view_set_task_list (GtdTaskListView *view,
@@ -1150,8 +1111,6 @@ gtd_task_list_view_get_show_list_name (GtdTaskListView *view)
  * @show_list_name: %TRUE to show list names, %FALSE to hide it
  *
  * Whether @view should should it's tasks' list name.
- *
- * Returns:
  */
 void
 gtd_task_list_view_set_show_list_name (GtdTaskListView *view,
@@ -1179,7 +1138,7 @@ gtd_task_list_view_set_show_list_name (GtdTaskListView *view,
 }
 
 /**
- * gtd_task_list_view_get)show_completed:
+ * gtd_task_list_view_get_show_completed:
  * @view: a #GtdTaskListView
  *
  * Returns %TRUE if completed tasks are visible, %FALSE otherwise.
@@ -1200,8 +1159,6 @@ gtd_task_list_view_get_show_completed (GtdTaskListView *view)
  * @show_completed: %TRUE to show completed tasks, %FALSE to hide them
  *
  * Sets the ::show-completed property to @show_completed.
- *
- * Returns:
  */
 void
 gtd_task_list_view_set_show_completed (GtdTaskListView *view,
@@ -1275,3 +1232,47 @@ gtd_task_list_view_set_show_completed (GtdTaskListView *view,
       g_object_notify (G_OBJECT (view), "show-completed");
     }
 }
+
+/**
+ * gtd_task_list_view_set_header_func:
+ * @view: a #GtdTaskListView
+ * @func: (closure user_data) (scope call) (nullable): the header function
+ * @user_data: data passed to @func
+ *
+ * Sets @func as the header function of @view. You can safely call
+ * %gtk_list_box_row_set_header from within @func.
+ *
+ * Do not unref nor free any of the passed data.
+ */
+void
+gtd_task_list_view_set_header_func (GtdTaskListView           *view,
+                                    GtdTaskListViewHeaderFunc  func,
+                                    gpointer                   user_data)
+{
+  GtdTaskListViewPrivate *priv;
+
+  g_return_if_fail (GTD_IS_TASK_LIST_VIEW (view));
+
+  priv = view->priv;
+
+  if (func)
+    {
+      priv->header_func = func;
+      priv->header_user_data = user_data;
+
+      gtk_list_box_set_header_func (priv->listbox,
+                                    (GtkListBoxUpdateHeaderFunc) internal_header_func,
+                                    view,
+                                    NULL);
+    }
+  else
+    {
+      priv->header_func = NULL;
+      priv->header_user_data = NULL;
+
+      gtk_list_box_set_header_func (priv->listbox,
+                                    NULL,
+                                    NULL,
+                                    NULL);
+    }
+}
